# Sympa::Constants.pm - This module contains all installation-related variables
# RCS Identication ; $Revision: 5768 $ ; $Date: 2009-05-21 16:23:23 +0200 (jeu. 21 mai 2009) $ 
#
# Sympa - SYsteme de Multi-Postage Automatique
# Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
# Copyright (c) 1997,1998, 1999 Institut Pasteur & Christophe Wolfhugel
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

package Sympa::Constants;
use strict;

use Exporter;
our @ISA = qw(Exporter);


use constant VERSION => '6.1.11';
use constant USER    => 'sympa';
use constant GROUP   => 'sympa';

use constant CONFIG           => '/usr/local/sympa-stable/etc/sympa.conf';
use constant WWSCONFIG        => '/usr/local/sympa-stable/etc/wwsympa.conf';
use constant SENDMAIL_ALIASES => '/etc/mail/aliases-sympa-stable';

use constant PIDDIR     => '/usr/local/sympa-stable';
use constant EXPLDIR    => '/usr/local/sympa-stable/list_data';
use constant SPOOLDIR   => '/usr/local/sympa-stable/spool';
use constant SYSCONFDIR => '/usr/local/sympa-stable/etc';
use constant LOCALEDIR  => '/usr/local/sympa-stable/locale';
use constant LIBEXECDIR => '/usr/local/sympa-stable/bin';
use constant SBINDIR    => '/usr/local/sympa-stable/bin';
use constant SCRIPTDIR  => '/usr/local/sympa-stable/bin';
use constant MODULEDIR  => '/usr/local/sympa-stable/bin';
use constant DEFAULTDIR => '/usr/local/sympa-stable/default';
use constant STATICDIR  => '/usr/local/sympa-stable/static_content';
use constant ARCDIR    => '/usr/local/sympa-stable/arc';
use constant BOUNCEDIR  => '/usr/local/sympa-stable/bounce';

1;
